@@ -3,9 +3,8 @@ This module installs npm packages
 """
 
 
-import subprocess
-
 from pydmt.utils.filesystem import unlink_files, mkdir_touch
+from pydmt.utils.subprocess import check_call
 
 from pydmt.api.one_source_one_target import OneSourceOneTarget
 
@@ -19,5 +18,5 @@ class Installer(OneSourceOneTarget):
             '--quiet',
             '--silent',
         ]
-        subprocess.check_call(args)
+        check_call(args)
         mkdir_touch(self.target)
